@@ -1209,6 +1209,9 @@ class yank(commands.Command):
 		"path" : "get_rel_path",
 		"relative path" : "get_rel_path",
 		"absolute path" : "get_abs_path",
+		"url/origin.git" : "get_url_origin_git",
+		"url/origin.web" : "get_url_origin_web",
+		"url/commit" : "get_url_commit",
 	}
 
 	@classmethod
@@ -1339,6 +1342,32 @@ class yank(commands.Command):
 			fn = os.path.abspath(fn)
 		return fn
 
+	def get_url_origin_git(self, hash_id: str, type_id: str) -> str:
+		"""The output of `git remote get-url origin`"""
+		cmd = ['git', 'remote', 'get-url', 'origin']
+		return self.run_and_get_output(cmd).rstrip('\n')
+
+	def get_url_origin_web(self, hash_id: str, type_id: str) -> str:
+		"""The website of the remote repository called origin"""
+		url = self.get_url_origin_git(hash_id, type_id)
+		url = url.rstrip('.git')
+		url = url.rstrip('/')
+		return url
+
+	def get_url_commit(self, hash_id: str, type_id: str) -> str:
+		"""The website of the current commit on the remote repository called origin"""
+		url = self.get_url_origin_web(hash_id, type_id)
+		url = url.rstrip('.git')
+		url = url.rstrip('/')
+		if 'github.com' in url:
+			url += '/commit/%H'
+		elif 'bitbucket.org' in url:
+			url += '/commits/%H'
+		else:
+			# gitlab
+			url += '/-/commit/%H'
+		return url
+
 
 	# ------- copy -------
 
