@@ -1366,6 +1366,10 @@ def initattr(obj, name, value):
 
 class Opener:
 
+	EDITOR_AUTO = 'auto'
+
+	default_editor = EDITOR_AUTO
+
 	def __init__(self):
 		settings
 		self._map = {}
@@ -1392,11 +1396,22 @@ class Opener:
 				# in case EDITOR is an absolute path
 				name = self._map.get(os.path.split(cmd)[1], None)
 		else:
-			name = "vi"
+			name = self.get_default_editor_name()
 			cmd = self.get_editor_argument(name, "command")
 			assert cmd
 		return name, cmd
 
+	def get_default_editor_name(self) -> str:
+		if self.default_editor != self.EDITOR_AUTO:
+			return self.default_editor
+
+		editors = ['vim', 'vi', 'nano']
+		for ed in editors:
+			if shutil.which(ed):
+				return ed
+
+		return 'vi'
+
 	def get_editor_argument(self, editor_name, argument_name):
 		return getattr(self, "editor_%s_%s" % (editor_name, argument_name), "")
 
